==> arf-4.1.1-en-download.zip: arf-4.1.1-en/webhelp/arf-webhelp/arf/navig/contents_arf.js <==
//
//	FindinSite-CD-JS-HelpIndex database eventreplicatorforadabas
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var eventreplicatorforadabas = {
    baseurls: ["../"],
    varname: "eventreplicatorforadabas",
    tree: [
        { url: "overview.htm", title: "Event Replicator for Adabas",
          tree: [
              { url: "relnotes/rnotes.htm", title: "Release Notes",
                tree: [
                    { url: "relnotes/enhancements.htm", title: "Enhancements" },
                    { url: "relnotes/zap.htm", title: "ZAP Information" },
                    { url: "relnotes/adacompat.htm", title: "Adabas and Event Replicator Server Compatibility" },
                    { url: "relnotes/ziip_support.htm", title: "zIIP Support" },
                    { url: "relnotes/eom.htm", title: "End of Maintenance" },
                    { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
                    { url: "relnotes/prevrel.htm", title: "Previous Release Notes" },
                ]
              },
              { url: "ars/ars-over.htm", title: "Adabas Replication Service for webMethods Integration Server",
                tree: [
                    { url: "ars/ars-general.htm", title: "General Information" },
                    { url: "ars/ars-inst.htm", title: "Installation" },
                    { url: "ars/ars-lic.htm", title: "License" },
                    { url: "ars/ars-config-is.htm", title: "Configuration - Integration Server" },
                    { url: "ars/ars-config-exx-adapter.htm", title: "Configuration - EntireX Adapter" },
                    { url: "ars/ars-rep-wiz.htm", title: "Using the Adabas Replication Wizard" },
                    { url: "ars/ars-doc-type.htm", title: "Create Document Type from Adabas File" },
                    { url: "ars/ars-designer.htm", title: "Using the Software AG Designer" },
                    { url: "ars/ars-scenarios.htm", title: "Common Scenarios" },
                    { url: "ars/ars-scenarios-usage.htm", title: "Common Usage Scenarios" },
                    { url: "ars/ars-scenarios-deploy.htm", title: "Common Deployment Scenarios" },
                    { url: "ars/ars-scenarios-direct.htm", title: "Simple Deployment Using Direct RPC" },
                    { url: "ars/ars-scenarios-broker.htm", title: "Deployment Using EntireX Broker" },
                    { url: "ars/ars-scenarios-direct-steps.htm", title: "Scenario: Notifying a User after an Adabas Database Record is Updated" },
                    { url: "ars/ars-scenarios-broker-steps.htm", title: "Scenario: Notifying a User after an Adabas Database Record is Updated" },
                    { url: "ars/ars-scenarios-troubleshooting.htm", title: "Troubleshooting" },
                ]
              },
              { url: "install/arfi_ov.htm", title: "Installation",
                tree: [
                    { url: "install/conv.htm", title: "Conventions" },
                    { url: "install/sysreq.htm", title: "System Requirements" },
                    { url: "install/arfitape.htm", title: "About the Installation Tape" },
                    { url: "install/arfizos.htm", title: "Event Replicator Installation Steps for z/OS Systems" },
                    { url: "install/arfiimp.htm", title: "Post-Installation Replication Implementation Steps" },
                    { url: "install/arfitest.htm", title: "Running in Verify Mode" },
                    { url: "install/sec.htm", title: "Security" },
                ]
              },
              { url: "intro/arfc_ov.htm", title: "Concepts and Facilities",
                tree: [
                    { url: "intro/arfcwhy.htm", title: "Why Use the Event Replicator for Adabas?" },
                    { url: "intro/arfcarch.htm", title: "Event Replicator for Adabas Architecture" },
                    { url: "intro/arfcproc.htm", title: "Replication Processing" },
                    { url: "intro/arfcop.htm", title: "Event Replicator for Adabas Operation and Administration" },
                    { url: "intro/arfcgo.htm", title: "Getting Started" },
                    { url: "intro/doclinks.htm", title: "Useful Documentation Links" },
                ]
              },
              { url: "admin/arfa_ov.htm", title: "Administration and Operations",
                tree: [
                    { url: "admin/arfaover.htm", title: "Replication Definition Overview and Maintenance" },
                    { url: "admin/arfarepl.htm", title: "Replaying Replicated Records" },
                    { url: "admin/arfaslog.htm", title: "Using the Subscription Logging Facility" },
                    { url: "admin/arfaflow.htm", title: "Reducing the Risk of Replication Pool Overflows" },
                    { url: "admin/arfatlog.htm", title: "Using Transaction Logging" },
                    { url: "admin/arfaexit.htm", title: "Using the Event Replicator Subscription User Exit" },
                    { url: "admin/arfamsg.htm", title: "Messaging System Integration" },
                    { url: "admin/arfafile.htm", title: "Creating a Sequential Output File" },
                    { url: "admin/arfasec.htm", title: "Replicating Security Definitions" },
                    { url: "admin/arfaop.htm", title: "Pertinent Operator Commands" },
                    { url: "admin/arfaaos.htm", title: "AOS Features Supporting Event Replicator for Adabas" },
                ]
              },
              { url: "gui/arfgover.htm", title: "Using the Adabas Event Replicator Subsystem",
                tree: [
                    { url: "gui/arfagui.htm", title: "About the Adabas Event Replicator Subsystem" },
                    { url: "gui/arfais.htm", title: "Maintaining Initial-State Definitions" },
                    { url: "gui/arfadest.htm", title: "Maintaining Destination Definitions" },
                    { url: "gui/arfaiq.htm", title: "Maintaining Input Queue (IQUEUE) Definitions" },
                    { url: "gui/arfarb.htm", title: "Maintaining Resend Buffer Definitions" },
                    { url: "gui/arfatf.htm", title: "Maintaining Transaction Filter Definitions" },
                    { url: "gui/arfasubs.htm", title: "Maintaining Subscription Definitions" },
                    { url: "gui/arfasfil.htm", title: "Maintaining SFILE Definitions" },
                    { url: "gui/arfagfb.htm", title: "Maintaining GFB Definitions" },
                    { url: "gui/arfgrepl.htm", title: "Initiating a Replay Request Using the Adabas Event Replicator Subsystem" },
                    { url: "gui/arfgplog.htm", title: "Reviewing and Managing the PLOG Data Set List" },
                    { url: "gui/arfatarg.htm", title: "Submitting Event Replicator Target Adapter Requests" },
                ]
              },
              { url: "messages/repmsg.htm", title: "Messages and Codes",
                tree: [
                    { url: "messages/ADAF.htm", title: "ADAF* - Event Replicator for Adabas Messages" },
                    { url: "messages/ADAI.htm", title: "ADAI* - ADAIOR System Messages" },
                    { url: "messages/ADAU.htm", title: "ADAU* Utility Status Messages" },
                    { url: "messages/ARF.htm", title: "ARF* - Adabas Event Replicator Subsystem Messages" },
                    { url: "messages/ART.htm", title: "ART* - Event Replicator Target Adapter Messages" },
                    { url: "messages/ARXB.htm", title: "ARBIN* - Event Replicator for Adabas ADARIS DCLASS=SAGTRGB Messages" },
                    { url: "messages/ARXM.htm", title: "ARXM* - Event Replicator for Adabas Messages for Event Replicator Target Adapter" },
                    { url: "messages/arfmutil.htm", title: "Adabas Utility Messages",
                      tree: [
                          { url: "messages/ADACNV.htm", title: "ADACNV Utility Messages" },
                          { url: "messages/ADADBS.htm", title: "ADADBS Utility Messages" },
                          { url: "messages/ADADEF.htm", title: "ADADEF Utility Messages" },
                          { url: "messages/ADALOD.htm", title: "ADALOD Utility Messages" },
                          { url: "messages/ADAMTR.htm", title: "ADAMTR Utility Messages" },
                          { url: "messages/ADAMTS.htm", title: "ADAMTS Utility Messages" },
                          { url: "messages/ADAORD.htm", title: "ADAORD Utility Messages" },
                          { url: "messages/ADAREP.htm", title: "ADAREP Utility Messages" },
                          { url: "messages/ADARIS.htm", title: "ADARIS Utility Messages" },
                          { url: "messages/ADARPE.htm", title: "ADARPE Utility Messages" },
                          { url: "messages/ADARPL.htm", title: "ADARPL Utility Messages" },
                          { url: "messages/ADARPP.htm", title: "ADARPP Utility Messages" },
                          { url: "messages/ADASAV.htm", title: "ADASAV Utility Messages" },
                      ]
                    },
                    { url: "messages/adarun.htm", title: "ADARUN Statement/Parameter Messages" },
                    { url: "messages/abends.htm", title: "User Abend Codes" },
                    { url: "messages/nucstart.htm", title: "Nucleus Startup Error Messages" },
                    { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                ]
              },
              { url: "program/arfpov.htm", title: "Application Programmer's Reference",
                tree: [
                    { url: "program/arfpmsum.htm", title: "Output Message Summary" },
                    { url: "program/arfpsamp.htm", title: "Sample Output Message" },
                    { url: "program/arfpmdet.htm", title: "Output Message Detail" },
                    { url: "program/arfpclrq.htm", title: "Event Replicator Client Requests" },
                    { url: "program/arfptstq.htm", title: "Testing webMethods EntireX and WebSphere MQ Queues" },
                ]
              },
              { url: "monitoring/arfmon_ov.htm", title: "Replication Monitoring",
                tree: [
                    { url: "monitoring/arfmon_overview.htm", title: "Replication Monitoring Overview" },
                    { url: "monitoring/arfmon_inst.htm", title: "Installing and Configuring Replication Monitoring" },
                    { url: "monitoring/arfmon_metrics.htm", title: "Replication Monitoring Metrics" },
                    { url: "monitoring/arfmon_events.htm", title: "Replication Monitoring Events" },
                ]
              },
              { url: "ref/arfr_ov.htm", title: "Reference",
                tree: [
                    { url: "ref/arf_conv.htm", title: "Conventions" },
                    { url: "ref/arfr_run.htm", title: "Pertinent ADARUN Parameters" },
                    { url: "ref/arfrutil.htm", title: "Utilities Used with Replication" },
                    { url: "ref/adadbs.htm", title: "ADADBS Utility Replication Functions" },
                    { url: "ref/adadef.htm", title: "ADADEF Utility Replication Functions" },
                    { url: "ref/adalod.htm", title: "ADALOD Utility Replication Functions" },
                    { url: "ref/adaord.htm", title: "ADAORD Utility Replication Functions" },
                    { url: "ref/adarep.htm", title: "ADAREP Report Description" },
                    { url: "ref/adasav.htm", title: "ADASAV Utility Replication Functions" },
                    { url: "ref/adares.htm", title: "ADARES Utility Replication Functions" },
                    { url: "ref/adaris.htm", title: "ADARIS Utility: Run Initial-State Process" },
                    { url: "ref/adarpe.htm", title: "ADARPE Utility: Extract TLOG Records" },
                    { url: "ref/adarpl.htm", title: "ADARPL Utility: PLOG Replication Replay" },
                    { url: "ref/adarpp.htm", title: "ADARPP Utility: Print TLOG Records" },
                    { url: "ref/rplod.htm", title: "RPULD and RPLOD Utilities" },
                    { url: "ref/arfrinit.htm", title: "Event Replicator Initialization Parameters" },
                    { url: "ref/c5.htm", title: "C5 Command: Write User Data to Protection Log" },
                ]
              },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: eventreplicatorforadabas });

==> arf-4.2.1-en-download.zip: arf-4.2.1-en/webhelp/arf-webhelp/arf/navig/contents_arf.js <==
//
//	FindinSite-CD-JS-HelpIndex database eventreplicatorforadabas
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var eventreplicatorforadabas = {
    baseurls: ["../"],
    varname: "eventreplicatorforadabas",
    tree: [
        { url: "overview.htm", title: "Event Replicator for Adabas",
          tree: [
              { url: "relnotes/rnotes.htm", title: "Release Notes",
                tree: [
                    { url: "relnotes/enhancements.htm", title: "Enhancements" },
                    { url: "relnotes/zap.htm", title: "ZAP Information" },
                    { url: "relnotes/adacompat.htm", title: "Adabas and Event Replicator Server Compatibility" },
                    { url: "relnotes/ziip_support.htm", title: "zIIP Support" },
                    { url: "relnotes/eom.htm", title: "End of Maintenance" },
                    { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
                    { url: "relnotes/prevrel.htm", title: "Previous Release Notes" },
                ]
              },
              { url: "ars/ars-over.htm", title: "Adabas Replication Service for webMethods Integration Server",
                tree: [
                    { url: "ars/ars-general.htm", title: "General Information" },
                    { url: "ars/ars-inst.htm", title: "Installation" },
                    { url: "ars/ars-lic.htm", title: "License" },
                    { url: "ars/ars-config-is.htm", title: "Configuration - Integration Server" },
                    { url: "ars/ars-config-exx-adapter.htm", title: "Configuration - EntireX Adapter" },
                    { url: "ars/ars-rep-wiz.htm", title: "Using the Adabas Replication Wizard" },
                    { url: "ars/ars-doc-type.htm", title: "Create Document Type from Adabas File" },
                    { url: "ars/ars-designer.htm", title: "Using the Software AG Designer" },
                    { url: "ars/ars-scenarios.htm", title: "Common Scenarios" },
                    { url: "ars/ars-scenarios-usage.htm", title: "Common Usage Scenarios" },
                    { url: "ars/ars-scenarios-deploy.htm", title: "Common Deployment Scenarios" },
                    { url: "ars/ars-scenarios-direct.htm", title: "Simple Deployment Using Direct RPC" },
                    { url: "ars/ars-scenarios-broker.htm", title: "Deployment Using EntireX Broker" },
                    { url: "ars/ars-scenarios-direct-steps.htm", title: "Scenario: Notifying a User after an Adabas Database Record is Updated" },
                    { url: "ars/ars-scenarios-broker-steps.htm", title: "Scenario: Notifying a User after an Adabas Database Record is Updated" },
                    { url: "ars/ars-scenarios-troubleshooting.htm", title: "Troubleshooting" },
                ]
              },
              { url: "install/arfi_ov.htm", title: "Installation",
                tree: [
                    { url: "install/conv.htm", title: "Conventions" },
                    { url: "install/sysreq.htm", title: "System Requirements" },
                    { url: "install/arfitape.htm", title: "About the Installation Tape" },
                    { url: "install/arfizos.htm", title: "Event Replicator Installation Steps for z/OS Systems" },
                    { url: "install/arfiimp.htm", title: "Post-Installation Replication Implementation Steps" },
                    { url: "install/arfitest.htm", title: "Running in Verify Mode" },
                    { url: "install/sec.htm", title: "Security" },
                ]
              },
              { url: "intro/arfc_ov.htm", title: "Concepts and Facilities",
                tree: [
                    { url: "intro/arfcwhy.htm", title: "Why Use the Event Replicator for Adabas?" },
                    { url: "intro/arfcarch.htm", title: "Event Replicator for Adabas Architecture" },
                    { url: "intro/arfcproc.htm", title: "Replication Processing" },
                    { url: "intro/arfcop.htm", title: "Event Replicator for Adabas Operation and Administration" },
                    { url: "intro/arfcgo.htm", title: "Getting Started" },
                    { url: "intro/doclinks.htm", title: "Useful Documentation Links" },
                ]
              },
              { url: "admin/arfa_ov.htm", title: "Administration and Operations",
                tree: [
                    { url: "admin/arfaover.htm", title: "Replication Definition Overview and Maintenance" },
                    { url: "admin/arfarepl.htm", title: "Replaying Replicated Records" },
                    { url: "admin/arfaslog.htm", title: "Using the Subscription Logging Facility" },
                    { url: "admin/arfaflow.htm", title: "Reducing the Risk of Replication Pool Overflows" },
                    { url: "admin/arfatlog.htm", title: "Using Transaction Logging" },
                    { url: "admin/arfaexit.htm", title: "Using the Event Replicator Subscription User Exit" },
                    { url: "admin/arfamsg.htm", title: "Messaging System Integration" },
                    { url: "admin/arfafile.htm", title: "Creating a Sequential Output File" },
                    { url: "admin/arfasec.htm", title: "Replicating Security Definitions" },
                    { url: "admin/arf_change_status.htm", title: "Changing the Status of Destinations and Subscriptions" },
                    { url: "admin/arfaop.htm", title: "Pertinent Operator Commands" },
                    { url: "admin/arfaaos.htm", title: "AOS Features Supporting Event Replicator for Adabas" },
                ]
              },
              { url: "gui/arfgover.htm", title: "Using the Adabas Event Replicator Subsystem",
                tree: [
                    { url: "gui/arfagui.htm", title: "About the Adabas Event Replicator Subsystem" },
                    { url: "gui/arfais.htm", title: "Maintaining Initial-State Definitions" },
                    { url: "gui/arfadest.htm", title: "Maintaining Destination Definitions" },
                    { url: "gui/arfaiq.htm", title: "Maintaining Input Queue (IQUEUE) Definitions" },
                    { url: "gui/arfarb.htm", title: "Maintaining Resend Buffer Definitions" },
                    { url: "gui/arfatf.htm", title: "Maintaining Transaction Filter Definitions" },
                    { url: "gui/arfasubs.htm", title: "Maintaining Subscription Definitions" },
                    { url: "gui/arfasfil.htm", title: "Maintaining SFILE Definitions" },
                    { url: "gui/arfagfb.htm", title: "Maintaining GFB Definitions" },
                    { url: "gui/arfgrepl.htm", title: "Initiating a Replay Request Using the Adabas Event Replicator Subsystem" },
                    { url: "gui/arfgplog.htm", title: "Reviewing and Managing the PLOG Data Set List" },
                    { url: "gui/arfatarg.htm", title: "Submitting Event Replicator Target Adapter Requests" },
                ]
              },
              { url: "messages/repmsg.htm", title: "Messages and Codes",
                tree: [
                    { url: "messages/ADAF.htm", title: "ADAF* - Event Replicator for Adabas Messages" },
                    { url: "messages/ADAI.htm", title: "ADAI* - ADAIOR System Messages" },
                    { url: "messages/ADAU.htm", title: "ADAU* Utility Status Messages" },
                    { url: "messages/ARF.htm", title: "ARF* - Adabas Event Replicator Subsystem Messages" },
                    { url: "messages/ART.htm", title: "ART* - Event Replicator Target Adapter Messages" },
                    { url: "messages/ARXB.htm", title: "ARBIN* - Event Replicator for Adabas ADARIS DCLASS=SAGTRGB Messages" },
                    { url: "messages/ARXM.htm", title: "ARXM* - Event Replicator for Adabas Messages for Event Replicator Target Adapter" },
                    { url: "messages/arfmutil.htm", title: "Adabas Utility Messages",
                      tree: [
                          { url: "messages/ADACNV.htm", title: "ADACNV Utility Messages" },
                          { url: "messages/ADADBS.htm", title: "ADADBS Utility Messages" },
                          { url: "messages/ADADEF.htm", title: "ADADEF Utility Messages" },
                          { url: "messages/ADALOD.htm", title: "ADALOD Utility Messages" },
                          { url: "messages/ADAMTR.htm", title: "ADAMTR Utility Messages" },
                          { url: "messages/ADAMTS.htm", title: "ADAMTS Utility Messages" },
                          { url: "messages/ADAORD.htm", title: "ADAORD Utility Messages" },
                          { url: "messages/ADAREP.htm", title: "ADAREP Utility Messages" },
                          { url: "messages/ADARIS.htm", title: "ADARIS Utility Messages" },
                          { url: "messages/ADARPE.htm", title: "ADARPE Utility Messages" },
                          { url: "messages/ADARPL.htm", title: "ADARPL Utility Messages" },
                          { url: "messages/ADARPP.htm", title: "ADARPP Utility Messages" },
                          { url: "messages/ADASAV.htm", title: "ADASAV Utility Messages" },
                      ]
                    },
                    { url: "messages/adarun.htm", title: "ADARUN Statement/Parameter Messages" },
                    { url: "messages/abends.htm", title: "User Abend Codes" },
                    { url: "messages/nucstart.htm", title: "Nucleus Startup Error Messages" },
                    { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                ]
              },
              { url: "program/arfpov.htm", title: "Application Programmer's Reference",
                tree: [
                    { url: "program/arfpmsum.htm", title: "Output Message Summary" },
                    { url: "program/arfpsamp.htm", title: "Sample Output Message" },
                    { url: "program/arfpmdet.htm", title: "Output Message Detail" },
                    { url: "program/arfpclrq.htm", title: "Event Replicator Client Requests" },
                    { url: "program/arfptstq.htm", title: "Testing IBM EntireX and WebSphere MQ Queues" },
                ]
              },
              { url: "monitoring/arfmon_ov.htm", title: "Replication Monitoring",
                tree: [
                    { url: "monitoring/arfmon_overview.htm", title: "Replication Monitoring Overview" },
                    { url: "monitoring/arfmon_inst.htm", title: "Installing and Configuring Replication Monitoring" },
                    { url: "monitoring/arfmon_metrics.htm", title: "Replication Monitoring Metrics" },
                    { url: "monitoring/arfmon_events.htm", title: "Replication Monitoring Events" },
                ]
              },
              { url: "ref/arfr_ov.htm", title: "Reference",
                tree: [
                    { url: "ref/arf_conv.htm", title: "Conventions" },
                    { url: "ref/arfr_run.htm", title: "Pertinent ADARUN Parameters" },
                    { url: "ref/arfrutil.htm", title: "Utilities Used with Replication" },
                    { url: "ref/adadbs.htm", title: "ADADBS Utility Replication Functions" },
                    { url: "ref/adadef.htm", title: "ADADEF Utility Replication Functions" },
                    { url: "ref/adalod.htm", title: "ADALOD Utility Replication Functions" },
                    { url: "ref/adaord.htm", title: "ADAORD Utility Replication Functions" },
                    { url: "ref/adarep.htm", title: "ADAREP Report Description" },
                    { url: "ref/adasav.htm", title: "ADASAV Utility Replication Functions" },
                    { url: "ref/adares.htm", title: "ADARES Utility Replication Functions" },
                    { url: "ref/adaris.htm", title: "ADARIS Utility: Run Initial-State Process" },
                    { url: "ref/adarpe.htm", title: "ADARPE Utility: Extract TLOG Records" },
                    { url: "ref/adarpl.htm", title: "ADARPL Utility: PLOG Replication Replay" },
                    { url: "ref/adarpp.htm", title: "ADARPP Utility: Print TLOG Records" },
                    { url: "ref/rplod.htm", title: "RPULD and RPLOD Utilities" },
                    { url: "ref/arfrinit.htm", title: "Event Replicator Initialization Parameters" },
                    { url: "ref/c5.htm", title: "C5 Command: Write User Data to Protection Log" },
                ]
              },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: eventreplicatorforadabas });
